import { ComputedRef } from 'vue';
import { Ref } from 'vue';

/**
 * 工具函数
 */
/**
 * 将Data URL转换为Blob对象
 * @param dataurl Data URL字符串
 * @returns Blob对象
 */
export declare function dataURLtoBlob(dataurl: string): Blob;

/**
 * 获取Blob对象的URL
 * @param file Blob对象
 * @returns 对象URL
 */
export declare function getObjectURL(file: Blob): string | null;

/**
 * PDF转图片功能Hook
 * 提供PDF文件加载、页面渲染、图片转换等功能
 * 支持缓存已转换的图片，提高性能
 */
/**
 * PDF转图片的配置选项接口
 */
export declare interface PdfToImageOptions {
    scale?: number;
    quality?: number;
    type?: string;
    maxCachePages?: number;
    preloadCount?: number;
    retryCount?: number;
    retryDelay?: number;
    adaptiveScale?: boolean;
}

/**
 * PDF转图片Hook函数
 * @returns 返回PDF转图片相关的状态和方法
 */
export declare function usePdf2img(): {
    imageCache: Ref<(string | null)[], (string | null)[]>;
    isLoading: Ref<boolean, boolean>;
    currentPage: Ref<number, number>;
    totalPages: Ref<number, number>;
    loadPdfFile: (url: string, userOptions?: PdfToImageOptions) => Promise<void>;
    currentImageUrl: ComputedRef<string | null>;
    renderPageToImage: (pageNumber: number, retryOptions?: {
        currentRetry?: number;
    }) => Promise<string | null>;
    convertAllPages: (userOptions?: PdfToImageOptions) => Promise<(string | null)[]>;
    nextPage: () => Promise<number>;
    prevPage: () => Promise<number>;
    cleanup: () => void;
};

export { }
